Welcome to ISAR
===============

ISAR (Integration and Supervisory control of Autonomous Robots) is a tool for integrating robot applications into Equinor systems.

Features
--------

- Communication with robots
- Scheduling and supervision of missions
- Collection of results

The ISAR system consists of a state machine and Python Flask API.

Contents
--------

.. toctree::
   :maxdepth: 4

   Getting started <readme_link>
   api/modules

* :ref:`genindex`
* :ref:`search`
